@@ -163,7 +163,7 @@ class SharePoint(object):
         old_fn = os.listdir(self.save_dir)[0]
         if os.path.isfile(self.save_dir+old_fn):
             if old_fn.startswith("OneDrive_") and old_fn.endswith(".zip"):
-                new_fn = folder_items_i[0]
+                new_fn = folder_items_i[0]+".zip"
             else:
                 new_fn = old_fn
             shutil.move(self.save_dir+old_fn, self.save_dir+current_folder+"\\"+new_fn)
